# Strategais

## 🚀 Quick Install

```pip install strategais```

Then run 

```python -m strategais -t Hello -p 8181 --env prod.env```

## Additional Flags

| Short Flag | Long Flag | Default Value | Description |
|------------|-----------|---------------|-------------|
| -t | --title | 'Strategais Server' | The title of the server. |
| -d | --description | 'Strategais Server' | The description of the server. |
| -p | --port | 8000 | The port to serve the server on. |
| -e | --env | 'main.env' | The .env file to load. |
| -l | --llm | 'path/hfagent_llm.py' | The path to the Python file that defines the LLM to use. |
| -h | --html | 'path/to/other.html' | The path to the HTML file to use. |

## 🤔 What is this?

Strategais is a powerful Python library designed to streamline the deployment of web applications powered by Large Language Models (LLMs). This library is built with the developer in mind, providing a suite of tools and utilities that simplify the process of setting up, developing, and deploying LLM-based web applications in a local environment or airgapped environment.

